const std = @import("std");
const io = std.io;
const fs = std.fs;
const mem = std.mem;
const heap = std.heap;
const fmt = std.fmt;
const posix = std.posix;
pub const Terminal = @import("terminal.zig");
pub const Control = @import("control.zig");
pub const Color = @import("color.zig").RGBA;

pub fn main() !void {
    var gpa = heap.GeneralPurposeAllocator(.{}){};
    defer _ = gpa.deinit();
    const allocator = gpa.allocator();

    var term = try Terminal.init(allocator);
    defer term.deinit();
    try term.clearScreen();
    try term.cursorHide();

    var box1 = Control.init(allocator);
    // defer box1.deinit();
    box1.border_bg = try Color.init("#3ace37ff");
    box1.top = 0;
    box1.bottom = 0;
    box1.left = 0;
    box1.right = 0;

    var box2 = Control.init(allocator);
    // defer box2.deinit();
    box2.border_bg = try Color.init("#000000c0");
    box2.content = "hi";
    box2.top = 1;
    box2.bottom = 3;
    box2.left = 20;
    box2.right = 2;

    var box3 = Control.init(allocator);
    // defer box3.deinit();
    box3.border_bg = try Color.init("#48d5eaa0");
    box3.content = "hello";
    box3.content_halign = .center;
    box3.content_valign = .center;
    box3.top = 2;
    box3.bottom = 1;
    box3.left = 20;
    box3.right = 20;

    try term.box.addChild(&box1);
    try box1.addChild(&box2);
    try box2.addChild(&box3);

    var running = true;
    while (running) {
        const events = try term.getEvents();
        defer allocator.free(events);
        for (events) |ev| switch (ev) {
            .system => {},
            .keyboard => {
                if (ev.keyboard.code == 'q') running = false;
                // box3.content = "Pressed " ++ &[_]u8{ev.keyboard.char};
                // box3.makeDirty();
            },
        };
        try term.draw();
        std.time.sleep(1000);
    }
}
